#
# spec file for package osv-scanner
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           osv-scanner
Version:        1.1.0
Release:        bp155.1.6
Summary:        Vulnerability scanner written in Go
License:        Apache-2.0
URL:            https://github.com/google/osv-scanner
Source:         osv-scanner-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
Use OSV-Scanner to find existing vulnerabilities affecting your project's dependencies.

OSV-Scanner provides an officially supported frontend to the OSV database that connects a project’s list of dependencies with the vulnerabilities that affect them. Since the OSV.dev database is open source and distributed, it has several benefits in comparison with closed source advisory databases and scanners:

- Each advisory comes from an open and authoritative source (e.g. the RustSec Advisory Database)
- Anyone can suggest improvements to advisories, resulting in a very high quality database
- The OSV format unambiguously stores information about affected versions in a machine-readable format that precisely maps onto a developer’s list of packages

The above all results in fewer, more actionable vulnerability notifications, which reduces the time needed to resolve them.

%prep
%setup -q
%setup -q -T -D -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.version=%{version} -X main.date=$BUILD_DATE -X main.commit=v%{version}" \
   -o bin/osv-scanner ./cmd/osv-scanner

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Thu Jan 12 2023 kastl@b1-systems.de
- Update to version 1.1.0:
  * Fix goreleaser permissions (#138)
  * v1.1.0 release PR (#137)
  * fix(deps): update osv-scanner minor (#79)
  * Temporarily disable alpine package scanning (#136)
  * Move tests from cloudbuild to gh actions (#135)
  * Use short url in scanner output (#134)
  * chore(deps): update workflows (#78)
  * Update readme and add changelog (#133)
  * fix: use correct ecosystem for NuGet (#132)
  * Do not highlight borders of result table (#131)
  * Add contributing file (#130)
  * Update README.md (#127)
  * docs: describe build process (#109)
  * Add gomodtidy after renovate updates (#120)
  * Make lint trigger same as others (#125)
  * Minor documentation updates. (#121)
  * Add support for Alpine Linux /lib/apk/db/installed (Resolves #72) (#107)
  * feat: add docker publish method (#70)
  * Add Pipenv lockfile support (Resolves #71) (#66)
  * Lint readme (#100)
  * Have renovate-bot label its PRs as it does with osv.dev (#116)
  * [pkg] implement NuGet ecosystem parser (#98)
  * Update github.com/spdx/gordf dependency to fix 32 bit support (#104)
  * test: update spec case and adjust assertion message (#99)
  * fix: ensure that files are closed when they're no longer needed (#106)
  * Fix lockfile example syntax (#103)
  * docs: add homebrew installation note (#89)
* Tue Dec 20 2022 Johannes Kastl <kastl@b1-systems.de>
- add build parameters, so 'osv-scanner --version' shows proper version,
  build date and the release tag as commit
* Tue Dec 20 2022 kastl@b1-systems.de
- Update to version 1.0.2:
  * shorten affected package to package (#90)
  * Move table columns so that the important column is displayed first (#87)
  * Add blog post link to README (#84)
  * Minor updates to install instruction title (#80)
  * Added installation instructions for Scoop (#68)
  * Update README.md (#77)
  * Fix readme anchor link. (#76)
  * Update README.md (#58)
  * Add disclaimer on Debian scanning. (#65)
  * Add gradle lockfile support (#46)
* Tue Dec 20 2022 Johannes Kastl <kastl@b1-systems.de>
- new package osv-scanner: Vulnerability scanner written in Go which uses the data provided by https://osv.dev
